@@ -1,6 +1,6 @@
 /* mpc_mul_fr -- Multiply a complex number by a floating-point number.
 
-Copyright (C) 2002, 2008, 2009, 2010, 2011 INRIA
+Copyright (C) 2002, 2008, 2009, 2010, 2011, 2012 INRIA
 
 This file is part of GNU MPC.
 
@@ -34,7 +34,7 @@ mpc_mul_fr (mpc_ptr a, mpc_srcptr b, mpfr_srcptr c, mpc_rnd_t rnd)
 
   inex_re = mpfr_mul (real, mpc_realref(b), c, MPC_RND_RE(rnd));
   inex_im = mpfr_mul (mpc_imagref(a), mpc_imagref(b), c, MPC_RND_IM(rnd));
-  mpfr_set (mpc_realref (a), real, GMP_RNDN); /* exact */
+  mpfr_set (mpc_realref (a), real, MPFR_RNDN); /* exact */
 
   if (c == mpc_realref (a))
     mpfr_clear (real);
