@@ -18,9 +18,9 @@ You should have received a copy of the GNU Lesser General Public License
 along with this program. If not, see http://www.gnu.org/licenses/ .
 */
 
-#include <stdio.h>
 #include <math.h>
 #include <inttypes.h> /* for the PRIi64 format modifier */
+#include <stdio.h>    /* for FILE */
 #include "mpc-impl.h"
 
 #define MPCR_MANT(r) ((r)->mant)
@@ -416,7 +416,6 @@ void mpcr_out_str (FILE *f, mpcr_srcptr r)
    }
 }
 
-
 static void mpcr_mul_rnd (mpcr_ptr r, mpcr_srcptr s, mpcr_srcptr t,
     mpfr_rnd_t rnd)
     /* Set r to the product of s and t, rounded according to whether rnd
